# Pressagio text prediction system

Pressagio is a library that predicts text based on n-gram models. For example,
you can send a string and the library will return the most likely word
completions for the last token in the string.

Pressagio is a pure Python port of the presage library: https://presage.sourceforge.io

Pressagio is part of the Poio project: https://www.poio.eu

## Running the tests

```
python -m unittest discover
```

## License

Pressagio source code is distributed under the Apache 2.0 License.
